@@ -3,11 +3,11 @@
 
 #include <QtGui>
 #include <QtWebKit>
-#include "glatitude.h"
-#include "gps.h"
 #ifdef Q_WS_MAEMO_5
 #include <QtMaemo5>
 #endif
+#include "glatitude.h"
+#include "gps.h"
 
 class LatitudeGUI : public QMainWindow {
     Q_OBJECT
@@ -17,23 +17,30 @@ public:
 
 private slots:
     void set();
-    void config();
-    void latitude_OK();
-    void latitude_ERROR();
-    void save_user(QString);
-    void save_pass(QString);
-    void save_freq(QString);
+    void set_config();
+    void latitude_ok();
+    void latitude_error();
+
     void maps_login();
     void mode_buzz();
     void mode_latitude();
+
     void mode_demonio();
 
+    void config();
+    void save_user(QString _user) { setting->setValue("user", _user); }
+    void save_pass(QString _pass) { setting->setValue("pass", _pass); }
+    void save_interval(QString _inter) { setting->setValue("interval", _inter.toInt()); }
+    void save_wait(QString _wait) { setting->setValue("wait", _wait.toInt()); }
+    void save_gps(int _c) { setting->setValue("usegps", (_c == Qt::Checked ? true : false)); }
+    void save_daemon(int _c) { setting->setValue("daemon", (_c == Qt::Checked ? true : false)); }
+
 private:
-    GoogleLatitude *glatitude;
-    GpsMaemo5 *gps;
     QSettings *setting;
+    GpsMaemo5 *gps;
+    GoogleLatitude *glatitude;
+
     QWebView *maps;
-    QUrl url;
     QAction *demonio;
 };
 
