@@ -6,8 +6,9 @@ int main(int argc, char *argv[]) {
     QCoreApplication::setApplicationName("GoogleLatitude");
 
     QApplication app(argc, argv);
-    LatitudeGUI *gui = new LatitudeGUI();
-    gui->show();
+
+    LatitudeGUI gui;
+    gui.show();
 
     return app.exec();
 }
